/* This test is part of GDB, the GNU debugger.

   Copyright 2017-2026 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#include <pthread.h>
#include <stdlib.h>

int __thread foo = 0xdeadbeef;

static void *
thread_proc (void *arg)
{
  abort ();
  return arg;
}

int
main (void)
{
  pthread_t thread;

  pthread_create (&thread, NULL, thread_proc, NULL);
  pthread_join (thread, NULL);

  return 0;
}
